@@ -1484,10 +1484,12 @@ def init_diagonostic():
     print ("test complete; Blowfish methods passed")
     print ("Testing Fernet methods")
     # using prev test file
+    # generating a key
+    key = cipher.generate_FerNet_key()
     # encrypting the file
-    cipher.FerNet_encrypt_file("test_file.txt")
+    cipher.FerNet_encrypt_file("test_file.txt", key)
     # decrypting the file
-    cipher.FerNet_decrypt_file("test_file.txt")
+    cipher.FerNet_decrypt_file("test_file.txt", key)
     # checking if the file is decrypted
     with open("test_file.txt", "r") as f:
         assert f.read() == "Hello World"
